% Calculate RBS strengths from GFP expression data
% using calc_production
function calc_rbs_strengths2()
    % matlab code exported by Gen5Parser
    d = load('rbs.mat');
    % .5 hour till 3 hour: 
    measure_range = 8:15;
%    measure_range = 25:96; % stationary state
    test_range = 1:72;
    x = (1:size(d.data,1)).* ( 1/6 );
    sampletimes = (0:length(measure_range)-1) * 10;
    
    strains = {
        'K398500A'
        'K398501A'
        'K398502A'
        'K398503A'
        'K398504A'
        'K173000A'
        'I13401'
        'LB+Amp'
    };

    rbsname = {
        'J61100' % A 1
        'J61117' % B 2
        'J61101' % C 3 
        'J61107' % D 4
        'J61127' % E 5
        'B0032'  % F 6
        'fluor blank' % G 7
        'abs blank' % H 8
    };

    % plot all graphs of J61100
    egfprange = 1:96;
    odrange = 97:192;

    gfp_data = d.data(:, egfprange);
    od_data = d.data(:, odrange);
    
    function cols = platerow(r) 
        cols = (r-1) * 12 + (1:12);
    end
    
    % mean blank GFP for each data row
    abs_blank_gfp = mean(gfp_data(:, platerow(8)), 2);
    abs_blank_od = mean(od_data(:, platerow(8)), 2);
    
    % subtract blank LB GFP and OD
    gfp_data(:, 1:(12*7)) = gfp_data(:, 1:(12*7)) - repmat(abs_blank_gfp, 1, 12*7);
    od_data(:, 1:(12*7)) = od_data(:, 1:(12*7)) - repmat(abs_blank_od, 1, 12*7);
    
    % control plasmid (GFP without promotor+rbs)
    % this shows that general biomass also results in a gfp measurement
    ctl_gfp = gfp_data(:, platerow(7));
    ctl_od = od_data(:, platerow(7));
    
    % calculate how much GFP is measured per biomass, without GFP being
    % actually present
    fake_gfp_per_od = mean(mean(ctl_gfp ./ ctl_od));
    
    fprintf('GFP / biomass in control plasmid: %f\n', fake_gfp_per_od);
    corrected_gfp = gfp_data(:, 1:72) - (fake_gfp_per_od * od_data(:, 1:72));
 
    gfp_od_data = corrected_gfp ./ od_data(:, 1:72);
    figure(1);
    plot (x, gfp_od_data);
    xlabel ('Time (hours)');
    ylabel ('Fluorescence (GFP) / absorbance (biomass)');

    figure(3);
    plot (x, od_data);
    xlabel ('Time (hours)');
    ylabel ('Absorbance (biomass)');
     
    production = zeros(length(test_range), 1);    
    for i = test_range
        % timestep in minutes
        duration = length(measure_range-1) * 10;
        od = od_data(measure_range, i);
        gfp = gfp_od_data(measure_range, i);

        [prod, mu] = calc_production(gfp', od', duration);
        production(i) = prod;
        
        fprintf('Found beta=%f, mu=%f\n', prod, mu);
    end

    mprod_ref = mean(production((1:12) + (6-1)*12));
    for i=1:6
        prod_rbs = production((1:12) + (i-1)*12);
        strengths = .3 * (prod_rbs ./ mprod_ref);
        boxplot_data(:, i) = strengths;
        strength_mean = mean(strengths);
        strength_std = std(strengths);
        fprintf('RBS %s strength = %f, std deviation: %f \n', rbsname{i}, strength_mean, strength_std);
    end
    figure(2);
    boxplot(boxplot_data, rbsname(1:6));
    ylabel('Relative RBS strength');
end
